var gather_locale_str_elements = function(parent_element) {
    var elements = parent_element.children;
    var locale_str_elements = [];
    for( var i = 0; elements[i]; i++ ) {
        if(elements[i].hasAttribute("locale_str")) {
            locale_str_elements.push(elements[i]);
        }
        Array.from(gather_locale_str_elements(elements[i])).forEach(
            elm => locale_str_elements.push(elm)
        );
    }

    return locale_str_elements;
}

var reload_localized_strings = function() {
    locale_str_elements = gather_locale_str_elements(document.body);
    Array.from(locale_str_elements).forEach(
        function(elm){
            elm.innerHTML = "";
            write_localized_string(elm.getAttribute("locale_str"), elm);
        }
    );
}

var choose_language = function(prefered_language) {
    var language = navigator.language || navigator.userLanguage;

    if(prefered_language !== null && prefered_language != '')
    {
        language = prefered_language;
    }
    return language;
}

var get_localized_str = function(key) {
    var localized_str = default_localized_string[key];
    if(key in localized_string) {
        localized_str = localized_string[key];
    } else {
        console.log("localized string " + key + " not available in " + used_language);
    }
    return localized_str;
}

var write_localized_string = function(key, elm) {
    const localized_str = get_localized_str(key);
    elm.insertAdjacentHTML('beforeend', localized_str);
}

var create_language_init_script = function(language) {
    const new_script = document.createElement("script");
    new_script.setAttribute("src", "assets/lang/" + language + ".js");
    new_script.setAttribute("onload", "reload_localized_strings();");
    return new_script;
}

var reinit_language = function(selected_language) {
    const new_script = create_language_init_script(selected_language);
    var language_node = document.getElementById("language_init");
    const old_script = language_node.querySelectorAll("script")[0];
    language_node.replaceChild(new_script, old_script);
}

var load_language_promise = null;

var check_predefined_language = function() {
    if(typeof get_predefined_language != "undefined") {
        load_language_promise = get_predefined_language();
        load_language_promise.then(function(result){
            var predefined_language = null;
            if(result.length > 0)
            {
                predefined_language = result[0];
            }
            selected_language = choose_language(predefined_language);
            reinit_language(selected_language);
        });    
    }
}

var open_troubleshooting_article = function () {
    open_url("https://www.autodesk.com/troubleshooting_analytics");
}

var open_urls_protocols_article = function () {
    open_url("https://www.autodesk.com/autodeskidentitymanager-urlsprotocols-allowlist");
}

var language_init = function(selected_language) {
    check_predefined_language();
    reload_localized_strings();
}

//Uncomment to test languages
// var get_predefined_language = function () {
//     // return Promise.resolve(["cs-CZ"]);
//     return Promise.resolve(["de-DE"]);
//     // return Promise.resolve(["en-US"]);
//     // return Promise.resolve(["fr-FR"]);
//     // return Promise.resolve(["hu-HU"]);
//     // return Promise.resolve(["it-IT"]);
//     // return Promise.resolve(["ja-JP"]);
//     // return Promise.resolve(["ko-KR"]);
//     // return Promise.resolve(["nl-NL"]);
//     // return Promise.resolve(["pl-PL"]);
//     // return Promise.resolve(["pt-BR"]);
//     // return Promise.resolve(["pt-PT"]);
//     // return Promise.resolve(["ru-RU"]);
//     // return Promise.resolve(["zh-CN"]);
//     // return Promise.resolve(["zh-TW"]);
// }