var sign_in_call_count = 0;
var close_window_called = false;

var is_device_login_supported = async function () {
    // Uncomment to test device login
    // return Promise.resolve(true);
    return await get_data("device_login_supported") === true;
}

var is_browser_login_supported = async function () {
    return await get_data("browser_login_supported") === true;
}

var get_device_login_data = async function () {
    return await get_data("device_login_data");
}

var sign_in = function() {
    sign_in_call_count++;
    on_event("sign_in_browser");
}

var close_window = function() {
    close_window_called = true;
    on_event("close");
}

var open_url = function (url) {
    on_event("open_url", url);
}

var connect = function() {
    on_event("connect");
}

var navigate_sign_in_device = function () {
    on_event("navigate_sign_in_device");
}

var navigate_sign_in_browser = function () {
    on_event("navigate_sign_in_browser");
}

var handle_sign_in_button_key_down = function(e) {
    if (e.key == 'Enter') {
        sign_in();
    }
}

var handle_connect_button_key_down = function(e) {
    if (e.key == 'Enter') {
        connect();
    }
}

var handle_sign_in_device_again_button_key_down = function(e) {
    if (e.key == 'Enter') {
        navigate_sign_in_device();
    }
}

var handle_html_key_down = function(e) {
    if (e.key == 'Escape') {
        close_window();
    }
}

var selected_scale = 1;
var set_scale = function() {
    var body = document.body;
    body.style.transform = 'scale(' + selected_scale + ')';
}

var load_selected_scale = null;
var check_selected_scale = function() {
    if(typeof get_predefined_scale != "undefined") {
        load_selected_scale = get_predefined_scale();
        load_selected_scale.then(function(result){
            selected_scale = result[0];
            set_scale();
        });    
    }
}

var utility_init = function() {
    check_selected_scale();
    set_scale();
}

document.addEventListener("DOMContentLoaded", (e) => {
    // Check if the get_data function is defined
    if (typeof get_data === 'undefined') {
        console.log('The get_data function is not defined.');
        get_data = function () {
            return Promise.resolve(undefined);
        }
    }

    // Check if the on_event function is defined
    if (typeof on_event !== 'undefined') {
        on_event("loaded");
        console.log('The on_event function is defined.');
    } else {
        console.log('The on_event function is not defined.');
    }
    load_container(getConnectingContainerHTML);

    // Do not remove these code for testing. Begin
    // load_container(getConnectionErrorContainerHTML);
    // load_container(getLoginWarningContainerHTML);
    // load_container(getSignInBrowserContainerHTML);
    // load_container(getSignInBrowserErrorContainerHTML);
    // load_container(getSignInDeviceContainerHTML);
    // load_container(getSignInDeviceGetCodeContainerHTML);
    // load_container(getSignInDeviceErrorContainerHTML);
    // After 5 seconds, load container with SignIn HTML
    // setTimeout(() => {
    //     load_container(getSignInBrowserContainerHTML);
    // }, 5000);
    // Do not remove these code for testing. End

});


/**
 * Loads and replaces content from a subpage.
 *
 * @param {Function} func - A function that returns HTML content for the subpage.
 * Possible values:
 * - getConnectingContainerHTML
 * - getConnectionErrorContainerHTML
 * - getLoginWarningContainerHTML
 * - getSignInBrowserContainerHTML
 * - getSignInBrowserErrorContainerHTML
 * - getSignInDeviceContainerHTML
 * - getSignInDeviceGetCodeContainerHTML
 * - getSignInDeviceErrorContainerHTML
 */
var load_container = async function (func) {
    let data = await func();
    let html = Array.isArray(data) && data.length > 0 ? data[0] : data;
    let callback = Array.isArray(data) && data.length > 1 ? data[1] : function () {};

    document.getElementById('div-subpage-container').innerHTML = html;
    reload_localized_strings();
    await callback();
}